"""Formulas that come directly from another source.

Examples:
  - the O2 consumption curve from Daniels Running Formula
  - the adjustment factor that Strava applies to speeds based on grade
    to come up with GAP.
"""
